#!/usr/local/bin/python
# encoding: utf-8
"""
*Given a mysql query, read the data from the database and return the results as a list of dictionaries (database rows)*

:Author:
    David Young

:Date Created:
    June 21, 2016
"""
################# GLOBAL IMPORTS ####################
import sys
import os
os.environ['TERM'] = 'vt100'
from fundamentals import tools


def readquery(
        sqlQuery,
        dbConn,
        log,
        quiet=False):
    """Given a mysql query, read the data from the database and return the results as a list of dictionaries (database rows)

    **Key Arguments:**
        - ``log`` -- the logger.
        - ``sqlQuery`` -- the MySQL command to execute
        - ``dbConn`` -- the db connection
        - ``quiet`` -- ignore mysql warnings and errors and move on. Be careful when setting this to true - damaging errors can easily be missed. Default *False*.

    **Return:**
        - ``rows`` -- the rows returned by the sql query

    **Usage:**

        .. code-block:: python 

            from fundamentals.mysql import readquery
            rows = readquery(
                log=log,
                sqlQuery=sqlQuery,
                dbConn=dbConn,
                quiet=False
            )
    """
    log.info('starting the ``readquery`` function')
    import MySQLdb
    import warnings
    warnings.filterwarnings('error', category=MySQLdb.Warning)

    rows = []

    try:
        cursor = dbConn.cursor(MySQLdb.cursors.DictCursor)
    except Exception as e:
        log.error('could not create the database cursor: %s' % (e, ))
        raise IOError('could not create the database cursor: %s' % (e, ))
    # EXECUTE THE SQL COMMAND
    try:
        cursor.execute(sqlQuery)
        rows = cursor.fetchall()
    except Exception as e:
        sqlQuery = sqlQuery[:1000]
        if quiet == False:
            log.warning(
                'MySQL raised an error - read command not executed.\n' + str(e) + '\nHere is the sqlQuery\n\t%(sqlQuery)s' % locals())
            raise e

    # CLOSE THE CURSOR
    try:
        cursor.close()
    except Exception as e:
        log.warning('could not close the db cursor ' + str(e) + '\n')

    log.info('completed the ``readquery`` function')
    return rows



#!/usr/local/bin/python
# encoding: utf-8
"""
*Write the contents of HTML documents from memory to individual files*

:Author:
    David Young

:Date Created:
    March 16, 2016
"""
################# GLOBAL IMPORTS ####################
import sys
import os
os.environ['TERM'] = 'vt100'
from fundamentals import tools


def _dump_files_to_local_drive(bodies, theseUrls, log):
    """
    *takes the files stored in memory and dumps them to the local drive*

    ****Key Arguments:****
      - ``bodies`` -- array of file data (currently stored in memory)
      - ``theseUrls`` -- array of local files paths to dump the file data into
      - ``log`` -- the logger

    **Return:**
      - ``None``
    """
    j = 0
    log.debug("attempting to write file data to local drive")
    log.debug('%s URLS = %s' % (len(theseUrls), str(theseUrls),))
    for body in bodies:
        try:
            if theseUrls[j]:
                with open(theseUrls[j], 'w') as f:
                    f.write(body)
                f.close()
            j += 1
        except Exception, e:
            log.error(
                "could not write downloaded file to local drive - failed with this error %s: " %
                (str(e),))
            return -1
    return



import os
import nose2
import nose2
import unittest
import shutil
import yaml
from fundamentals.files import recursive_directory_listing
from fundamentals.utKit import utKit

from fundamentals import tools

su = tools(
    arguments={"settingsFile": None},
    docString=__doc__,
    logLevel="DEBUG",
    options_first=False,
    projectName="fundamentals"
)
arguments, settings, log, dbConn = su.setup()

# load settings
stream = file(
    "/Users/Dave/.config/fundamentals/fundamentals.yaml", 'r')
settings = yaml.load(stream)
stream.close()

# SETUP AND TEARDOWN FIXTURE FUNCTIONS FOR THE ENTIRE MODULE
moduleDirectory = os.path.dirname(__file__)
utKit = utKit(moduleDirectory)
log, dbConn, pathToInputDir, pathToOutputDir = utKit.setupModule()
utKit.tearDownModule()


class test_recursive_directory_listing(unittest.TestCase):

    def test_recursive_directory_listing_function(self):

        from fundamentals.files import recursive_directory_listing
        theseFiles = recursive_directory_listing(
            log,
            baseFolderPath="/tmp",
            whatToList="all"
        )
        print theseFiles

        from fundamentals.files import recursive_directory_listing
        theseFiles = recursive_directory_listing(
            log,
            baseFolderPath="/tmp",
            whatToList="files"
        )
        print theseFiles

        from fundamentals.files import recursive_directory_listing
        theseFiles = recursive_directory_listing(
            log,
            baseFolderPath="/tmp",
            whatToList="dirs"
        )
        print theseFiles

        # x-print-testpage-for-pessto-marshall-web-object

    # x-class-to-test-named-worker-function
